<?php
// $Id:  $

/**
 * @file styles/boxed_corners.inc
 * Definition of the 'boxed_corners' panel style.
 * 
 * Based  on rounded_corner.inc from panels.module
 * 
 * BUT MUCH DUMBED DOWN so you can see the important bits, not the clever bits.
 *
 * @author dman http://coders.co.nz 
 */

// ---------------------------------------------------------------------------
// Panels hooks.

/**
 * Implementation of HOOK_STYLENAME_panels_styles().
 * 
 * Where HOOK is the modulename as normal, and STYLENAME matches this inc
 * filename.
 */
function boxer_boxed_corners_panels_styles() {
  return array(
    'boxed_corners' => array(
      'title' => t('Boxed corners'),
      'description' => t('Presents the panes or panels with a folded corner box around them'),
      'render panel' => 'boxer_boxed_corners_style_render_panel',
      'settings form' => 'boxer_boxed_corners_style_settings_form',
    ),
  );
}

// ---------------------------------------------------------------------------
// Panels style plugin callbacks.

/**
 * Render callback.
 * 
 * Declared by name in the HOOK_panels_style() above.
 *
 * @ingroup themeable
 */
function theme_boxer_boxed_corners_style_render_panel($display, $panel_id, $panes, $settings) {
  $output = '';
  foreach ($panes as $pane_id => $pane) {
    $text = panels_render_pane($pane, $display->content[$pane_id], $display);
    if ($text) {
      $output .= boxer_boxed_corners_box($text);
    }
  }
  boxer_add_boxed_corners_css($display);
  return $output;
}

/**
 * Generates the CSS and adds it to the current page head.
 *
 * Note this does NOT do anything that cannot already be done with CSS! It's
 * here to show what COULD be done if you wanted to mess around.
 * 
 * For something this trivial, you may as well add a normal css file BUT you can
 * also do contextual or code things by writing it dynamically.
 *
 * @param $display
 *   A Panels display object.
 */
function boxer_add_boxed_corners_css($display) {
  static $displays_used = array();
  if (empty($displays_used[$display->css_id])) {
    $idstr = empty($display->css_id) ? '.boxed-corner' : "#$display->css_id";
    $url = url( drupal_get_path('module', 'boxer') . '/images', array('absolute' => TRUE));
  
    #######################################
    $css = <<<EOF
  
      $idstr {
        padding-bottom:6px;
      }
      $idstr .boxed-corner-inner {
        border-left:1px solid #DDDDDD;
        border-top:1px solid #DDDDDD;
        background:transparent url($url/block-right-bottom-bg.gif) no-repeat scroll right bottom;
        overflow:hidden;
        padding:5px 5px 10px;
      }
  
EOF;
    #######################################
  
    drupal_set_html_head("<style type=\"text/css\" media=\"all\">\n$css</style>\n");
    $displays_used[$display->css_id] = TRUE;
  }
}

/**
 * Settings form callback.
 * 
 * Example stub function only
 * 
 * See the panels.module distribution for panels with extra settings.
 * 
 */
function boxer_boxed_corners_style_settings_form($style_settings) {
  $form['info'] = array(
    '#type' => 'markup',
    '#value' => t('No settings'),
  );
  return $form;
}



/**
 * Create the HTML for our boxed corner box.
 * 
 * This doesn't add much to the normal rendering. But you can mess with it now.
 *
 * @param $text
 *   The content of this rounded corner box.
 *
 * @return
 *   The created HTML.
 */
function boxer_boxed_corners_box($content) {
  #######################################
  return <<<EOF
  <div class="boxed-corner">
    <div class="boxed-corner-top"></div>
    <div class="boxed-corner-inner">
          $content
    </div>
    <div class="boxed-corner-bottom"></div>
  </div>
EOF;
  #######################################
}
